@@ -12,6 +12,7 @@ from pytype.pytd import pytd_utils
 
 log = logging.getLogger(__name__)
 _isinstance = abstract_utils._isinstance  # pylint: disable=protected-access
+_make = abstract_utils._make  # pylint: disable=protected-access
 
 
 def argname(i):
@@ -108,10 +109,15 @@ class Signature:
     self.annotations = annotations
 
   def _postprocess_annotation(self, name, annotation):
+    """Postprocess the given annotation."""
+    ctx = annotation.ctx
     if name == self.varargs_name:
-      return annotation.ctx.convert.create_new_varargs_value(annotation)
+      return _make("ParameterizedClass",
+                   ctx.convert.tuple_type, {abstract_utils.T: annotation}, ctx)
     elif name == self.kwargs_name:
-      return annotation.ctx.convert.create_new_kwargs_value(annotation)
+      params = {abstract_utils.K: ctx.convert.str_type,
+                abstract_utils.V: annotation}
+      return _make("ParameterizedClass", ctx.convert.dict_type, params, ctx)
     else:
       return annotation
 
@@ -192,13 +198,16 @@ class Signature:
     )
 
   @classmethod
-  def from_param_names(cls, name, param_names):
+  def from_param_names(cls, name, param_names, kwonly=False):
     """Construct a minimal signature from a name and a list of param names."""
+    names = tuple(param_names)
+    param_names = () if kwonly else names
+    kwonly_params = names if kwonly else ()
     return cls(
         name=name,
-        param_names=tuple(param_names),
+        param_names=param_names,
         varargs_name=None,
-        kwonly_params=(),
+        kwonly_params=kwonly_params,
         kwargs_name=None,
         defaults={},
         annotations={},
@@ -503,7 +512,7 @@ class Args(collections.namedtuple(
                   kwdict.get_instance_type_parameter(name, node).data)
               for name in (abstract_utils.K, abstract_utils.V)
           }
-          cls = ctx.convert.build_map_class(node, params)
+          cls = _make("ParameterizedClass", ctx.convert.dict_type, params, ctx)
         starstarargs = cls.instantiate(node)
       else:
         starstarargs = None
@@ -607,13 +616,10 @@ BadCall = collections.namedtuple("_", ["sig", "passed_args", "bad_param"])
 
 
 class BadParam(
-    collections.namedtuple("_", ["name", "expected", "protocol_error",
-                                 "noniterable_str_error"])):
+    collections.namedtuple("_", ["name", "expected", "error_details"])):
 
-  def __new__(cls, name, expected, protocol_error=None,
-              noniterable_str_error=None):
-    return super().__new__(cls, name, expected, protocol_error,
-                           noniterable_str_error)
+  def __new__(cls, name, expected, error_details=None):
+    return super().__new__(cls, name, expected, error_details)
 
 
 class InvalidParameters(FailedFunctionCall):
