@@ -2,7 +2,6 @@
 
 import collections
 import itertools
-import sys
 
 from pytype import utils
 from pytype.abstract import abstract
@@ -225,9 +224,6 @@ class AnnotationUtils(utils.ContextWeakrefMixin):
     """Convert a name -> raw_annot dict to annotations."""
     annotations = {}
     raw_items = raw_annotations.items()
-    if sys.version_info[:2] < (3, 6):
-      # Make sure annotation errors are reported in a deterministic order.
-      raw_items = sorted(raw_items, key=str)
     for name, t in raw_items:
       # Don't use the parameter name, since it's often something unhelpful
       # like `0`.
