@@ -525,6 +525,21 @@ class ImportPathsTest(_LoaderTest):
     """).strip()
     self.assertMultiLineEqual(pytd_utils.Print(ast), expected)
 
+  def test_star_import_in_circular_dep(self):
+    stub3_ast = self._import(stub1="""
+      from stub2 import Foo
+      from typing import Mapping as Mapping
+    """, stub2="""
+      from stub3 import Mapping
+      class Foo: ...
+    """, stub3="""
+      from stub1 import *
+    """)
+    self.assertEqual(stub3_ast.Lookup("stub3.Foo").type,
+                     pytd.ClassType("stub2.Foo"))
+    self.assertEqual(stub3_ast.Lookup("stub3.Mapping").type,
+                     pytd.ClassType("typing.Mapping"))
+
 
 class ImportTypeMacroTest(_LoaderTest):
 
@@ -804,7 +819,7 @@ class RecursiveAliasTest(_LoaderTest):
         name="a.X",
         type=pytd.GenericType(
             base_type=pytd.ClassType("builtins.list"),
-            parameters=(pytd.LateType("a.X"),)))
+            parameters=(pytd.LateType("a.X", recursive=True),)))
     self.assertEqual(actual_x, expected_x)
 
   def test_mutual_recursion(self):
@@ -819,7 +834,7 @@ class RecursiveAliasTest(_LoaderTest):
         name="a.X",
         type=pytd.GenericType(
             base_type=pytd.ClassType("builtins.list"),
-            parameters=(pytd.LateType("a.Y"),)))
+            parameters=(pytd.LateType("a.Y", recursive=True),)))
     self.assertEqual(actual_x, expected_x)
 
     actual_y = ast.Lookup("a.Y")
@@ -830,7 +845,7 @@ class RecursiveAliasTest(_LoaderTest):
             parameters=(
                 pytd.GenericType(
                     base_type=pytd.ClassType("builtins.list"),
-                    parameters=(pytd.LateType("a.Y"),)),)))
+                    parameters=(pytd.LateType("a.Y", recursive=True),)),)))
     self.assertEqual(actual_y, expected_y)
 
   def test_very_mutual_recursion(self):
@@ -846,7 +861,7 @@ class RecursiveAliasTest(_LoaderTest):
         name="a.X",
         type=pytd.GenericType(
             base_type=pytd.ClassType("builtins.list"),
-            parameters=(pytd.LateType("a.Y"),)))
+            parameters=(pytd.LateType("a.Y", recursive=True),)))
     self.assertEqual(actual_x, expected_x)
 
     actual_y = ast.Lookup("a.Y")
@@ -854,7 +869,7 @@ class RecursiveAliasTest(_LoaderTest):
         name="a.Y",
         type=pytd.GenericType(
             base_type=pytd.ClassType("builtins.list"),
-            parameters=(pytd.LateType("a.Z"),)))
+            parameters=(pytd.LateType("a.Z", recursive=True),)))
     self.assertEqual(actual_y, expected_y)
 
     actual_z = ast.Lookup("a.Z")
@@ -865,7 +880,7 @@ class RecursiveAliasTest(_LoaderTest):
             parameters=(
                 pytd.GenericType(
                     base_type=pytd.ClassType("builtins.list"),
-                    parameters=(pytd.LateType("a.Y"),)),)))
+                    parameters=(pytd.LateType("a.Y", recursive=True),)),)))
     self.assertEqual(actual_z, expected_z)
 
 
