@@ -8,7 +8,6 @@ from pytype import overlay
 from pytype import overlay_utils
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
-from pytype.abstract import class_mixin
 from pytype.abstract import function
 from pytype.abstract import mixin
 from pytype.overlays import classgen
@@ -35,6 +34,7 @@ class AttrOverlay(overlay.Overlay):
         "attrs": Attrs.make,
         "attrib": Attrib.make,
         "s": Attrs.make,
+        "dataclass": Attrs.make_dataclass,
         "ib": Attrib.make,
         "Factory": Factory.make,
 
@@ -60,7 +60,7 @@ class AttrOverlay(overlay.Overlay):
 class _NoChange():
   pass
 
-# A unique sentinal value to signal not to write anything, not even the
+# A unique sentinel value to signal not to write anything, not even the
 # original value.
 _NO_CHANGE = _NoChange()
 
@@ -72,6 +72,12 @@ class Attrs(classgen.Decorator):
   def make(cls, ctx):
     return super().make("s", ctx, "attr")
 
+  @classmethod
+  def make_dataclass(cls, ctx):
+    ret = super().make("s", ctx, "attr")
+    ret.partial_args["auto_attribs"] = True
+    return ret
+
   def init_name(self, attr):
     # attrs removes leading underscores from attrib names when generating kwargs
     # for __init__.
@@ -443,7 +449,7 @@ class Attrib(classgen.FieldConstructor):
     if not converter_var:
       return None, None
     converter = converter_var.data[0]
-    if isinstance(converter, class_mixin.Class):
+    if isinstance(converter, abstract.Class):
       # If the converter is a class, set the field type to the class and the
       # init type to Any.
       # TODO(b/135553563): Check that converter.__init__ takes one argument and
