@@ -3,10 +3,8 @@
 import dataclasses
 import hashlib
 import sys
-import typing
 from typing import Any, List, Optional, Tuple, Union
 
-from pytype import utils
 from pytype.ast import debug
 from pytype.pyi import classdef
 from pytype.pyi import conditions
@@ -22,16 +20,19 @@ from pytype.pytd import pytd_utils
 from pytype.pytd import visitors
 from pytype.pytd.codegen import decorate
 from pytype.pytd.codegen import pytdgen
-from typed_ast import ast3
 
+# pylint: disable=g-import-not-at-top
+if sys.version_info >= (3, 8):
+  import ast as ast3
+else:
+  from typed_ast import ast3
+# pylint: enable=g-import-not-at-top
 
 _DEFAULT_PLATFORM = "linux"
 
-
 # reexport as parser.ParseError
 ParseError = types.ParseError
 
-
 _TYPEVAR_IDS = ("TypeVar", "typing.TypeVar")
 _PARAMSPEC_IDS = (
     "ParamSpec", "typing.ParamSpec", "typing_extensions.ParamSpec")
@@ -43,12 +44,11 @@ _NEWTYPE_IDS = ("NewType", "typing.NewType")
 _ANNOTATED_IDS = (
     "Annotated", "typing.Annotated", "typing_extensions.Annotated")
 
-
 #------------------------------------------------------
 # imports
 
 
-def _tuple_of_import(alias: ast3.AST) -> Tuple[str, str]:
+def _tuple_of_import(alias: ast3.alias) -> Union[str, Tuple[str, str]]:
   """Convert a typedast import into one that add_import expects."""
   if alias.asname is None:
     return alias.name
@@ -76,7 +76,7 @@ class _TypeVar:
   constraints: List[Any]
 
   @classmethod
-  def from_call(cls, node: ast3.AST) -> "_TypeVar":
+  def from_call(cls, node: ast3.Call) -> "_TypeVar":
     """Construct a _TypeVar from an ast.Call node."""
     name, *constraints = node.args
     bound = None
@@ -101,8 +101,8 @@ class _ParamSpec:
   name: str
 
   @classmethod
-  def from_call(cls, node: ast3.AST) -> "_ParamSpec":
-    name, = node.args
+  def from_call(cls, node: ast3.Call) -> "_ParamSpec":
+    name, = node.args  # pytype: disable=bad-unpacking
     return cls(name)
 
 
@@ -141,7 +141,7 @@ class AnnotationVisitor(visitor.BaseVisitor):
         return self.defs.new_type(annotation)
       a = ast3.parse(annotation)
       # Unwrap the module the parser puts around the source string
-      typ = a.body[0].value
+      typ = a.body[0].value  # pytype: disable=attribute-error
       return self.visit(typ)
     except ParseError as e:
       # Clear out position information since it is relative to the typecomment
@@ -152,8 +152,8 @@ class AnnotationVisitor(visitor.BaseVisitor):
     ret = MetadataVisitor().visit(node)
     return ret if ret is not None else node
 
-  def visit_Constant(self, node):
-    # Handle a types.Constant node (converted from a literal constant).
+  def visit_Pyval(self, node):
+    # Handle a types.Pyval node (converted from a literal constant).
     # We do not handle the mixed case
     #   x: List['int']
     # since we need to not convert subscripts for typing.Literal, i.e.
@@ -185,11 +185,27 @@ class AnnotationVisitor(visitor.BaseVisitor):
     else:
       return self.defs.new_type(node.id)
 
+  def visit_Call(self, node):
+    raise ParseError("Constructors and function calls in type annotations "
+                     "are not supported.")
+
+  def _get_subscript_params(self, node):
+    if sys.version_info >= (3, 9):
+      return node.slice
+    else:
+      return node.slice.value
+
+  def _set_subscript_params(self, node, new_val):
+    if sys.version_info >= (3, 9):
+      node.slice = new_val
+    else:
+      node.slice.value = new_val
+
   def _convert_typing_annotated(self, node):
-    typ, *args = node.slice.value.elts
+    typ, *args = self._get_subscript_params(node).elts
     typ = self.visit(typ)
     params = (self.convert_metadata(x) for x in args)
-    node.slice.value = (typ,) + tuple(params)
+    self._set_subscript_params(node, (typ,) + tuple(params))
 
   def enter_Subscript(self, node):
     if isinstance(node.value, ast3.Attribute):
@@ -199,7 +215,7 @@ class AnnotationVisitor(visitor.BaseVisitor):
     self.subscripted.append(node.value)
 
   def visit_Subscript(self, node):
-    params = node.slice.value
+    params = self._get_subscript_params(node)
     if type(params) is not tuple:  # pylint: disable=unidiomatic-typecheck
       params = (params,)
     return self.defs.new_type(node.value, params)
@@ -264,25 +280,22 @@ class Splice:
     return str(self)
 
 
-class GeneratePytdVisitor(visitor.BaseVisitor):
+class _GeneratePytdVisitor(visitor.BaseVisitor):
   """Converts a typed_ast tree to a pytd tree."""
 
-  def __init__(self, src, filename, module_name, version, platform,
-               gen_stub_imports):
-    defs = definitions.Definitions(
-        modules.Module(filename, module_name, gen_stub_imports))
+  def __init__(self, src, filename, module_name, options):
+    defs = definitions.Definitions(modules.Module(filename, module_name))
     super().__init__(defs=defs, filename=filename)
     self.src_code = src
     self.module_name = module_name
-    self.version = version
-    self.platform = platform or _DEFAULT_PLATFORM
+    self.options = options
     self.level = 0
     self.in_function = False  # pyi will not have nested defs
     self.annotation_visitor = AnnotationVisitor(defs=defs, filename=filename)
     self.class_stack = []
 
   def show(self, node):
-    print(debug.dump(node, ast3, include_attributes=False))
+    print(debug.dump(node, ast3, include_attributes=True))
 
   def convert_node(self, node):
     # Converting a node via a visitor will convert the subnodes, but if the
@@ -318,7 +331,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     if node.value == self.defs.ELLIPSIS:
       # class x: ...
       return node.value
-    elif types.Constant.is_str(node.value):
+    elif types.Pyval.is_str(node.value):
       # docstrings
       return Splice([])
 
@@ -364,10 +377,10 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     # constant or alias from a partially converted typed_ast subtree.
     if name == "__slots__":
       if not (isinstance(value, ast3.List) and
-              all(types.Constant.is_str(x) for x in value.elts)):
+              all(types.Pyval.is_str(x) for x in value.elts)):
         raise ParseError("__slots__ must be a list of strings")
       return types.SlotDecl(tuple(x.value for x in value.elts))
-    elif isinstance(value, types.Constant):
+    elif isinstance(value, types.Pyval):
       return pytd.Constant(name, value.to_pytd())
     elif isinstance(value, types.Ellipsis):
       return pytd.Constant(name, pytd.AnythingType())
@@ -465,7 +478,8 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
   def enter_If(self, node):
     # Evaluate the test and preemptively remove the invalid branch so we don't
     # waste time traversing it.
-    node.test = conditions.evaluate(node.test, self.version, self.platform)
+    node.test = conditions.evaluate(
+        node.test, self.options.python_version, self.options.platform)
     if not isinstance(node.test, bool):
       raise ParseError("Unexpected if statement" + debug.dump(node, ast3))
 
@@ -498,7 +512,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     self.defs.add_import(module, imports)
     return Splice([])
 
-  def _convert_newtype_args(self, node: ast3.AST):
+  def _convert_newtype_args(self, node: ast3.Call):
     if len(node.args) != 2:
       msg = "Wrong args: expected NewType(name, [(field, type), ...])"
       raise ParseError(msg)
@@ -506,7 +520,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     typ = self.convert_node(typ)
     node.args = [name.s, typ]
 
-  def _convert_typing_namedtuple_args(self, node: ast3.AST):
+  def _convert_typing_namedtuple_args(self, node: ast3.Call):
     # TODO(mdemello): handle NamedTuple("X", a=int, b=str, ...)
     if len(node.args) != 2:
       msg = "Wrong args: expected NamedTuple(name, [(field, type), ...])"
@@ -516,14 +530,14 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     fields = [(types.string_value(n), t) for (n, t) in fields]
     node.args = [name.s, fields]
 
-  def _convert_collections_namedtuple_args(self, node: ast3.AST):
+  def _convert_collections_namedtuple_args(self, node: ast3.Call):
     if len(node.args) != 2:
       msg = "Wrong args: expected namedtuple(name, [field, ...])"
       raise ParseError(msg)
     name, fields = node.args
     fields = self.convert_node(fields)
     fields = [(types.string_value(n), pytd.AnythingType()) for n in fields]
-    node.args = [name.s, fields]
+    node.args = [name.s, fields]  # pytype: disable=attribute-error
 
   def _convert_typevar_args(self, node):
     self.annotation_visitor.visit(node.keywords)
@@ -536,7 +550,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     # Special-case late types in bound since typeshed uses it.
     for kw in node.keywords:
       if kw.arg == "bound":
-        if isinstance(kw.value, types.Constant):
+        if isinstance(kw.value, types.Pyval):
           val = types.string_value(kw.value, context="TypeVar bound")
           kw.value = self.annotation_visitor.convert_late_annotation(val)
 
@@ -544,7 +558,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     name, = node.args
     node.args = [name.s]
 
-  def _convert_typed_dict_args(self, node: ast3.AST):
+  def _convert_typed_dict_args(self, node: ast3.Call):
     # TODO(b/157603915): new_typed_dict currently doesn't do anything with the
     # args, so we don't bother converting them fully.
     msg = "Wrong args: expected TypedDict(name, {field: type, ...})"
@@ -557,7 +571,7 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
   def enter_Call(self, node):
     # Some function arguments need to be converted from strings to types when
     # entering the node, rather than bottom-up when they would already have been
-    # converted to types.Constant.
+    # converted to types.Pyval.
     # We also convert some literal string nodes that are not meant to be types
     # (e.g. the first arg to TypeVar()) to their bare values since we are
     # passing them to internal functions directly in visit_Call.
@@ -650,66 +664,71 @@ def post_process_ast(ast, src, name=None):
     # information if an error is raised during transformation of a class node.
     raise ParseError.from_exc(e)
 
-  # Typeshed files that explicitly import and refer to "__builtin__" need to
-  # have that rewritten to builtins
-  ast = ast.Visit(visitors.RenameBuiltinsPrefix())
-
   return ast
 
 
 def _parse(src: str, feature_version: int, filename: str = ""):
   """Call the typed_ast parser with the appropriate feature version."""
+  kwargs = {"feature_version": feature_version}
+  if sys.version_info >= (3, 8):
+    kwargs["type_comments"] = True
   try:
-    ast_root_node = ast3.parse(src, filename, feature_version=feature_version)
+    ast_root_node = ast3.parse(src, filename, **kwargs)  # pylint: disable=unexpected-keyword-arg
   except SyntaxError as e:
     raise ParseError(e.msg, line=e.lineno, filename=filename) from e
   return ast_root_node
 
 
-# Python version input type.
-VersionType = Union[int, Tuple[int, ...]]
-
-
-def _feature_version(python_version: VersionType) -> int:
+def _feature_version(python_version: Tuple[int, ...]) -> int:
   """Get the python feature version for the parser."""
-  if isinstance(python_version, int):
+  if len(python_version) == 1:
     return sys.version_info.minor
   else:
-    python_version = typing.cast(Tuple[int, ...], python_version)
-    if len(python_version) == 1:
-      return sys.version_info.minor
-    else:
-      return python_version[1]
+    return python_version[1]
+
+
+# Options that will be copied from pytype.config.Options.
+_TOPLEVEL_PYI_OPTIONS = (
+    "python_version",
+)
+
+
+@dataclasses.dataclass
+class PyiOptions:
+  """Pyi parsing options."""
+
+  python_version: Tuple[int, int] = sys.version_info[:2]
+  platform: str = _DEFAULT_PLATFORM
+
+  @classmethod
+  def from_toplevel_options(cls, toplevel_options):
+    kwargs = {}
+    for k in _TOPLEVEL_PYI_OPTIONS:
+      kwargs[k] = getattr(toplevel_options, k)
+    return cls(**kwargs)
 
 
 def parse_string(
     src: str,
-    python_version: VersionType = 3,
     name: Optional[str] = None,
     filename: Optional[str] = None,
-    platform: Optional[str] = None,
-    gen_stub_imports: bool = True,
+    options: Optional[PyiOptions] = None,
 ):
-  return parse_pyi(src, filename=filename, module_name=name,
-                   platform=platform, python_version=python_version,
-                   gen_stub_imports=gen_stub_imports)
+  return parse_pyi(src, filename=filename, module_name=name, options=options)
 
 
 def parse_pyi(
     src: str,
     filename: Optional[str],
     module_name: str,
-    python_version: VersionType = 3,
-    platform: Optional[str] = None,
-    gen_stub_imports: bool = True,
+    options: Optional[PyiOptions] = None,
 ) -> pytd.TypeDeclUnit:
   """Parse a pyi string."""
   filename = filename or ""
-  feature_version = _feature_version(python_version)
-  python_version = utils.normalize_version(python_version)
+  options = options or PyiOptions()
+  feature_version = _feature_version(options.python_version)
   root = _parse(src, feature_version, filename)
-  gen_pytd = GeneratePytdVisitor(
-      src, filename, module_name, python_version, platform, gen_stub_imports)
+  gen_pytd = _GeneratePytdVisitor(src, filename, module_name, options)
   root = gen_pytd.visit(root)
   root = post_process_ast(root, src, module_name)
   return root
@@ -719,16 +738,14 @@ def parse_pyi_debug(
     src: str,
     filename: str,
     module_name: str,
-    python_version: VersionType = 3,
-    platform: Optional[str] = None,
-) -> Tuple[pytd.TypeDeclUnit, GeneratePytdVisitor]:
+    options: Optional[PyiOptions] = None,
+) -> Tuple[pytd.TypeDeclUnit, _GeneratePytdVisitor]:
   """Debug version of parse_pyi."""
-  feature_version = _feature_version(python_version)
-  python_version = utils.normalize_version(python_version)
+  options = options or PyiOptions()
+  feature_version = _feature_version(options.python_version)
   root = _parse(src, feature_version, filename)
   print(debug.dump(root, ast3, include_attributes=False))
-  gen_pytd = GeneratePytdVisitor(
-      src, filename, module_name, python_version, platform, True)
+  gen_pytd = _GeneratePytdVisitor(src, filename, module_name, options)
   root = gen_pytd.visit(root)
   print("---transformed parse tree--------------------")
   print(root)
@@ -741,11 +758,9 @@ def parse_pyi_debug(
   return root, gen_pytd
 
 
-def canonical_pyi(pyi, python_version=3, multiline_args=False,
-                  gen_stub_imports=True):
+def canonical_pyi(pyi, multiline_args=False, options=None):
   """Rewrite a pyi in canonical form."""
-  ast = parse_string(pyi, python_version=python_version,
-                     gen_stub_imports=gen_stub_imports)
+  ast = parse_string(pyi, options=options)
   ast = ast.Visit(visitors.ClassTypeToNamedType())
   ast = ast.Visit(visitors.CanonicalOrderingVisitor(sort_signatures=True))
   ast.Visit(visitors.VerifyVisitor())
